@@ -24,13 +24,7 @@
 */
 
 #include <config.h>
-#include <glib.h>
 #include <string.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtksignal.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtk.h>
 
 #include "gtkhtml.h"
 #include "gtkhtml-properties.h"
@@ -961,7 +955,7 @@ html_image_set_border (HTMLImage *image, gint border)
 }
 
 void
-html_image_set_alt (HTMLImage *image, gchar *alt)
+html_image_set_alt (HTMLImage *image, const gchar *alt)
 {
 	g_free (image->alt);
 	image->alt = g_strdup (alt);
